.. image:: https://travis-ci.org/IMIO/imio.prettylink.svg?branch=master
   :target: https://travis-ci.org/IMIO/imio.prettylink

.. image:: https://coveralls.io/repos/IMIO/imio.prettylink/badge.png?branch=master
   :target: https://coveralls.io/r/IMIO/imio.prettylink?branch=master


====================
imio.prettylink
====================

Manage generation of a pretty link to an element including coloration, leading icons, ...
